# link_extractor

Extract Links from news source, ranked by importance.

## usage

```
import link_extractor
link_extractor.getLinks(webpage, domain=domain)
```

## how to install

`pip3 install link_extractor`